@@ -8,9 +8,12 @@ import yaml
 from io import open
 from abaqus import mdb
 from abaqusConstants import STANDARD_EXPLICIT
-from abml import abml_helpers
 import interaction
 from abaqus import openMdb
+import logging
+import abml_helpers
+
+logger = logging.getLogger(__name__)
 
 
 class Abml_Registry:
@@ -26,7 +29,7 @@ class Abml_Registry:
 
 
 @Abml_Registry.register("cae")
-class Abml_Cae:
+class Abml_Cae(abml_helpers.Abml_History):
     def __init__(self, models, **kwargs):
         self.kwargs = kwargs
 
@@ -180,12 +183,10 @@ class Abml_Model:
             if sketches is not None:
                 sketches = OrderedDict(sorted(sketches.items()))
 
-                sketch_name = sketches.keys()[0]
-                sketch_cmds = sketches.values()[0]
-
-                self.sketches.update(
-                    {sketch_name: to_object_cmd_mode(sketch_cmds, "sketch", model=self, name=sketch_name)}
-                )
+                for sketch_name, sketch_cmds in sketches.items():
+                    self.sketches.update(
+                        {sketch_name: to_object_cmd_mode(sketch_cmds, "sketch", model=self, name=sketch_name)}
+                    )
 
     def create_materials(self, **kwargs):
         materials_list = [value for key, value in kwargs.items() if "materials" in key]
@@ -280,6 +281,11 @@ class Abml_Model:
 
     def create(self):
         if self.name not in mdb.models.keys():
+            info = {
+                "call": "mdb.Model",
+                "kwargs": {"modelType": "STANDARD_EXPLICIT", "name": self.name},
+            }
+            logger.info(info)
             mdb.Model(modelType=STANDARD_EXPLICIT, name=self.name)
 
         if "Model-1" in mdb.models.keys():
