@@ -43,7 +43,13 @@ class Abml_Interaction:
             "interactionProperty": self.kwargs["interaction_prop"],
         }
 
-        self.model.m.SurfaceToSurfaceContactStd(**kwargs)
+        try:
+            self.model.m.SurfaceToSurfaceContactStd(**kwargs)
+        except ValueError as e:
+            error_str = "interaction_name = {}\n".format(self.name)
+            error_str += "interactionProperty = {}\n".format(self.kwargs["interaction_prop"])
+            error_str += "{e}".format(e=e)
+            raise ValueError(error_str)
 
     def elastic_foundation(self):
         try:
