@@ -1,6 +1,8 @@
 import logging
-import logging.config
 
+# import logging.config
+
+logger = logging.getLogger("abml_logger")
 
 # debug_level = logging.CRITICAL
 
