@@ -6,14 +6,17 @@ from abaqusConstants import ON, OFF, STANDALONE  # noqa
 from regionToolset import Region
 from abml_dataclass import Abml_Registry
 from abml_dataclass import to_object_option_mode, to_object_key_mode, to_object_cmd_mode
-from abml_helpers import Abml_Helpers
+from abml_helpers import Abml_Helpers, Abml_History
 from abml_sketch import Abml_Sketch
 from numpy import array, abs
 from abaqus import mdb
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 @Abml_Registry.register("parts")
-class Abml_Part:
+class Abml_Part(Abml_History):
     """
     A class representing a part in an Abaqus/Explicit model.
 
@@ -142,7 +145,13 @@ class Abml_Part:
 
     def create(self):
         if self.name not in self.model.parts.keys():
-            self.model.m.Part(dimensionality=THREE_D, name=self.name, type=DEFORMABLE_BODY)
+            kwargs = {"dimensionality": THREE_D, "name": self.name, "type": DEFORMABLE_BODY}
+            info = {
+                "call": 'mdb.models["{}"].Part'.format(self.model.name),
+                "kwargs": abml_helpers.convert_kwargs_to_string(kwargs),
+            }
+            logger.info(info)
+            self.model.m.Part(**kwargs)
 
     def get_sequence_from_set_list(self, set_list):
         face_seq = None
