@@ -2,6 +2,9 @@ import abml_helpers
 from abml.abml_dataclass import Abml_Registry
 from numpy import array
 from abaqusConstants import COUNTERCLOCKWISE, CLOCKWISE
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 @Abml_Registry.register("sketch")
@@ -28,7 +31,13 @@ class Abml_Sketch:
 
     def create(self):
         if self.name not in self.model.m.sketches.keys():
-            self.model.m.ConstrainedSketch(name=self.name, sheetSize=200.0)
+            kwargs = {"name": self.name, "sheetSize": 200.0}
+            info = {
+                "call": 'mdb.models["{}"].ConstrainedSketch'.format(self.model.name),
+                "kwargs": kwargs,
+            }
+            logger.info(info)
+            self.model.m.ConstrainedSketch(**kwargs)
         self._sketch_reg.get(self.type, self._create_sketch_rect)(**self.kwargs)
 
         if "construction_line" in self.kwargs:
@@ -39,26 +48,57 @@ class Abml_Sketch:
         s.ConstructionLine(point1=(0.0, -100.0), point2=(0.0, 100.0))
 
     def _create_sketch_rect(self, p1, p2):
+        kwargs = {"point1": p1, "point2": p2}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].rectangle'.format(self.model.name, self.name),
+            "kwargs": kwargs,
+        }
+        logger.info(info)
         s = self.model.m.sketches[self.name]
-        s.rectangle(point1=p1, point2=p2)
+        s.rectangle(**kwargs)
 
     def _create_sketch_line(self, p1, p2):
+        kwargs = {"point1": p1, "point2": p2}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].Line'.format(self.model.name, self.name),
+            "kwargs": kwargs,
+        }
+        logger.info(info)
         s = self.model.m.sketches[self.name]
-        s.Line(point1=p1, point2=p2)
+        s.Line(**kwargs)
 
     def _create_sketch_pline(self, points):
         s = self.model.m.sketches[self.name]
         lines = create_lines_from_points(array(points))
         for line in lines:
-            s.Line(point1=line[0].astype(float), point2=line[1].astype(float))
+            kwargs = {"point1": line[0].astype(float), "point2": line[1].astype(float)}
+            info = {
+                "call": 'mdb.models["{}"].sketches["{}"].Line'.format(self.model.name, self.name),
+                "kwargs": abml_helpers.convert_kwargs_to_string(kwargs),
+            }
+            abml_helpers.cprint(info)
+            logger.info(info)
+            s.Line(**kwargs)
 
     def _create_sketch_circle(self, center, r):
+        kwargs = {"center": center, "point1": r}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].CircleByCenterPerimeter'.format(self.model.name, self.name),
+            "kwargs": kwargs,
+        }
+        logger.info(info)
         s = self.model.m.sketches[self.name]
-        s.CircleByCenterPerimeter(center=center, point1=r)
+        s.CircleByCenterPerimeter(**kwargs)
 
     def _create_sketch_ellipse(self, center, r1, r2):
+        kwargs = {"center": center, "axisPoint1": r1, "axisPoint2": r2}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].EllipseByCenterPerimeter'.format(self.model.name, self.name),
+            "kwargs": kwargs,
+        }
+        logger.info(info)
         s = self.model.m.sketches[self.name]
-        s.EllipseByCenterPerimeter(center=center, axisPoint1=r1, axisPoint2=r2)
+        s.EllipseByCenterPerimeter(**kwargs)
 
     def _create_sketch_arc_c2p(self, center, p1, p2, **kwargs):
         s = self.model.m.sketches[self.name]
@@ -72,11 +112,23 @@ class Abml_Sketch:
             "clockwise": COUNTERCLOCKWISE,
         }
 
-        s.ArcByCenterEnds(center=center, point1=p1, point2=p2, direction=direction_reg[direction.lower()])
+        kwargs = {"center": center, "point1": p1, "point2": p2, "direction": direction_reg[direction.lower()]}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].ArcByCenterEnds'.format(self.model.name, self.name),
+            "kwargs": abml_helpers.convert_kwargs_to_string(kwargs),
+        }
+        logger.info(info)
+
+        s.ArcByCenterEnds(**kwargs)
 
     def _create_sketch_arc_3p(self, p1, p2, p3):
         s = self.model.m.sketches[self.name]
-
+        kwargs = {"point1": p1, "point2": p1, "point3": p3}
+        info = {
+            "call": 'mdb.models["{}"].sketches["{}"].Arc3Points'.format(self.model.name, self.name),
+            "kwargs": kwargs,
+        }
+        logger.info(info)
         s.Arc3Points(point1=p1, point2=p2, point3=p3)
 
     def _autotrim(self, p1):
@@ -85,7 +137,13 @@ class Abml_Sketch:
         geometries = self._point_on_geometry(p1)
 
         for geometry in geometries:
-            s.autoTrimCurve(curve1=geometry, point1=p1, parameter1=None)  # noqq
+            kwargs = {"curve1": geometry, "point1": p1, "parameter1": None}
+            info = {
+                "call": 'mdb.models["{}"].sketches["{}"].Arc3Points'.format(self.model.name, self.name),
+                "kwargs": abml_helpers.convert_kwargs_to_string(kwargs),
+            }
+            logger.info(info)
+            s.autoTrimCurve(**kwargs)  # noqq
 
     def _point_on_geometry(self, p1):
         s = self.model.m.sketches[self.name]
